@@ -51,7 +51,7 @@ struct Store {
     List stores;
 
     Store(const QUrl &u, const QString &name, Store *s)
-            : url(u), folder(new Folder(name.toUtf8() + '/')), parent(s) { }
+            : url(u), folder(new Folder((name + QLatin1Char('/')).toUtf8().constData())), parent(s) { }
 
 
     Store* propagate()
@@ -89,8 +89,8 @@ RemoteLister::RemoteLister(const QUrl &url, QWidget *parent, ScanManager* manage
     setMainWindow(parent);
 
     // Use SIGNAL(result(KIO::Job*)) instead and then use Job::error()
-    connect(this, static_cast<void (KCoreDirLister::*)()>(&KCoreDirLister::completed), this, &RemoteLister::completed);
-    connect(this, static_cast<void (KCoreDirLister::*)()>(&KCoreDirLister::canceled), this, &RemoteLister::canceled);
+    connect(this, static_cast<void (KCoreDirLister::*)()>(&KCoreDirLister::completed), this, &RemoteLister::onCompleted);
+    connect(this, static_cast<void (KCoreDirLister::*)()>(&KCoreDirLister::canceled), this, &RemoteLister::onCanceled);
 }
 
 RemoteLister::~RemoteLister()
@@ -98,15 +98,14 @@ RemoteLister::~RemoteLister()
     delete m_root;
 }
 
-void
-RemoteLister::canceled()
+void RemoteLister::onCanceled()
 {
     qDebug() << "Canceled";
     emit branchCompleted(nullptr);
     deleteLater();
 }
 
-void RemoteLister::completed()
+void RemoteLister::onCompleted()
 {
     //m_folder is set to the folder we should operate on
 
@@ -116,7 +115,7 @@ void RemoteLister::completed()
         if (it->isDir())
             m_store->stores += new Store(it->url(), it->name(), m_store);
         else
-            m_store->folder->append(it->name().toUtf8(), it->size());
+            m_store->folder->append(it->name().toUtf8().constData(), it->size());
 
         m_manager->m_files++;
     }
